@@ -5,8 +5,7 @@
 
   SPDX-License-Identifier: GPL-2.0-or-later WITH Qt-Commercial-exception-1.0
 */
-#ifndef CALENDARSUPPORT_MAILCLIENT_H
-#define CALENDARSUPPORT_MAILCLIENT_H
+#pragma once
 
 #include <KCalendarCore/IncidenceBase>
 
@@ -94,4 +93,3 @@ private:
 };
 }
 
-#endif
