@@ -81,6 +81,16 @@
 #include <QStackedWidget>
 #include <QVBoxLayout>
 
+// Meaningful aliases for dialog box return codes.
+enum ItemActions {
+    Cancel = KMessageBox::Cancel,  // Do nothing.
+    Current = KMessageBox::Ok,  // Selected recurrence only.
+    AlsoFuture = KMessageBox::No,  // Selected and future recurrences.
+    Parent = KMessageBox::Yes,  // Instance, but not child instances.
+    All = KMessageBox::Continue,  // Instance and child instances.
+};
+
+
 CalendarView::CalendarView(QWidget *parent)
     : CalendarViewBase(parent)
     , mSearchCollectionHelper(this)
@@ -151,7 +161,7 @@ CalendarView::CalendarView(QWidget *parent)
     mEventViewer->setObjectName(QStringLiteral("EventViewer"));
     mEventViewerBoxVBoxLayout->addWidget(mEventViewer);
 
-    QWidget *rightBox = new QWidget(mPanner);
+    auto rightBox = new QWidget(mPanner);
     auto rightBoxVBoxLayout = new QVBoxLayout(rightBox);
     rightBoxVBoxLayout->setContentsMargins({});
     mNavigatorBar = new NavigatorBar(rightBox);
@@ -469,7 +479,7 @@ void CalendarView::writeFilterSettings(KConfig *config)
     }
 
     filterList.reserve(mFilters.count());
-    for (KCalendarCore::CalFilter *filter : qAsConst(mFilters)) {
+    for (KCalendarCore::CalFilter *filter : std::as_const(mFilters)) {
         filterList << filter->name();
         KConfigGroup filterConfig(config, QStringLiteral("Filter_") + filter->name());
         filterConfig.writeEntry("Criteria", filter->criteria());
@@ -784,30 +794,18 @@ void CalendarView::edit_paste()
         endDT = agendaView->selectionEnd();
         useEndTime = !agendaView->selectedIsSingleCell();
         if (agendaView->selectedIsAllDay()) {
-#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
-            finalDateTime = QDateTime(date);
-#else
             finalDateTime = QDateTime(date.startOfDay());
-#endif
         } else {
             finalDateTime = QDateTime(date, agendaView->selectionStart().time());
         }
     } else if (curView == monthView && monthView->selectionStart().isValid()) {
-#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
-        finalDateTime = QDateTime(monthView->selectionStart().date());
-#else
         finalDateTime = QDateTime(monthView->selectionStart().date().startOfDay());
-#endif
         pasteFlags = KCalUtils::DndFactory::FlagPasteAtOriginalTime;
     } else if (!mDateNavigator->selectedDates().isEmpty() && curView->supportsDateNavigation()) {
         // default to the selected date from the navigator
         const KCalendarCore::DateList dates = mDateNavigator->selectedDates();
         if (!dates.isEmpty()) {
-#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
-            finalDateTime = QDateTime(dates.first());
-#else
             finalDateTime = QDateTime(dates.first().startOfDay());
-#endif
             pasteFlags = KCalUtils::DndFactory::FlagPasteAtOriginalTime;
         }
     }
@@ -1104,11 +1102,7 @@ void CalendarView::newJournal(const QString &text, QDate date)
     IncidenceEditorNG::IncidenceDefaults defaults = IncidenceEditorNG::IncidenceDefaults::minimalIncidenceDefaults();
 
     KCalendarCore::Journal::Ptr journal(new KCalendarCore::Journal);
-#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
-    defaults.setStartDateTime(QDateTime(date));
-#else
     defaults.setStartDateTime(QDateTime(date.startOfDay()));
-#endif
     defaults.setDefaults(journal);
 
     journal->setSummary(text);
@@ -1242,10 +1236,16 @@ bool CalendarView::incidence_unsub(const Akonadi::Item &item)
     const KCalendarCore::Incidence::Ptr inc = CalendarSupport::incidence(item);
 
     if (!inc || inc->relatedTo().isEmpty()) {
-        qCDebug(KORGANIZER_LOG) << "Refusing to unparent this to-do" << inc;
+        qCDebug(KORGANIZER_LOG) << "Refusing to unparent this instance" << inc;
         return false;
     }
 
+    for (const auto &instance : mCalendar->instances(inc)) {
+        KCalendarCore::Incidence::Ptr oldInstance(instance->clone());
+        instance->setRelatedTo(QString());
+        (void) mChanger->modifyIncidence(mCalendar->item(instance), oldInstance, this);
+    }
+
     KCalendarCore::Incidence::Ptr oldInc(inc->clone());
     inc->setRelatedTo(QString());
     (void) mChanger->modifyIncidence(item, oldInc, this);
@@ -1255,12 +1255,13 @@ bool CalendarView::incidence_unsub(const Akonadi::Item &item)
 
 bool CalendarView::makeSubTodosIndependent()
 {
-    bool status = false;
     const Akonadi::Item aTodo = selectedTodo();
 
-    if (makeChildrenIndependent(aTodo)) {
+    startMultiModify(i18n("Make sub-to-dos independent"));
+    bool status = makeChildrenIndependent(aTodo);
+    endMultiModify();
+    if (status) {
         updateView();
-        status = true;
     }
     return status;
 }
@@ -1275,13 +1276,11 @@ bool CalendarView::makeChildrenIndependent(const Akonadi::Item &item)
         qCDebug(KORGANIZER_LOG) << "Refusing to  make children independent" << inc;
         return false;
     }
-    startMultiModify(i18n("Make sub-to-dos independent"));
 
     for (const Akonadi::Item &item : subIncs) {
         incidence_unsub(item);
     }
 
-    endMultiModify();
     return true;
 }
 
@@ -1339,8 +1338,12 @@ void CalendarView::toggleTodoCompleted(const Akonadi::Item &todoItem)
 
     if (todo->isCompleted()) {
         todo->setPercentComplete(0);
+        todo->setCompleted(false);
+        todo->setStatus(KCalendarCore::Incidence::StatusNone);
     } else {
+        todo->setPercentComplete(0);
         todo->setCompleted(QDateTime::currentDateTime());
+        todo->setStatus(KCalendarCore::Incidence::StatusCompleted);
     }
 
     mChanger->startAtomicOperation(i18n("Toggle To-do Completed"));
@@ -1652,7 +1655,7 @@ void CalendarView::schedule(KCalendarCore::iTIPMethod method, const Akonadi::Ite
 
 void CalendarView::openAddressbook()
 {
-    KIO::CommandLauncherJob *job = new KIO::CommandLauncherJob(QStringLiteral("kaddressbook"), {}, this);
+    auto job = new KIO::CommandLauncherJob(QStringLiteral("kaddressbook"), {}, this);
     job->setDesktopName(QStringLiteral("org.kde.kaddressbook"));
     job->setUiDelegate(new KDialogJobUiDelegate(KJobUiDelegate::AutoHandlingEnabled, this));
     job->start();
@@ -1839,7 +1842,7 @@ void CalendarView::updateFilter()
     }
 
     filters << i18n("No filter");
-    for (KCalendarCore::CalFilter *filter : qAsConst(mFilters)) {
+    for (KCalendarCore::CalFilter *filter : std::as_const(mFilters)) {
         if (filter) {
             filters << filter->name();
         }
@@ -2119,77 +2122,67 @@ bool CalendarView::editIncidence(const Akonadi::Item &item, bool isCounter)
     }
 
     IncidenceEditorNG::IncidenceDialog *dialog = incidenceDialog(item);
-
-    // connectIncidenceEditor( dialog );         // TODO: This as well
     dialog->load(item, activeIncidenceDate()); // Show the dialog as soon as it loads the item.
 
     return true;
 }
 
-void CalendarView::deleteSubTodosIncidence(const Akonadi::Item &todoItem)
+void CalendarView::deleteIncidenceFamily(const Akonadi::Item &item)
 {
-    const KCalendarCore::Todo::Ptr todo = CalendarSupport::todo(todoItem);
-    if (!todo) {
+    const auto incidence = CalendarSupport::incidence(item);
+    if (!incidence) {
         return;
     }
-    const Akonadi::Item::List subTodos = mCalendar->childItems(todoItem.id());
-    for (const Akonadi::Item &item : subTodos) {
-        if (CalendarSupport::hasTodo(item)) {
-            deleteSubTodosIncidence(item);
+    deleteChildren(item);
+    deleteRecurringIncidence(item);
+}
+
+void CalendarView::deleteChildren(const Akonadi::Item &item)
+{
+    const auto incidence = CalendarSupport::incidence(item);
+    if (incidence && !incidence->hasRecurrenceId()) {
+        const Akonadi::Item::List childItems = mCalendar->childItems(item.id());
+        for (const Akonadi::Item &c : childItems) {
+            deleteIncidenceFamily(c);
         }
     }
+}
 
+void CalendarView::deleteRecurringIncidence(const Akonadi::Item &todoItem)
+{
     if (!mChanger->deletedRecently(todoItem.id())) {
+        auto incidence = CalendarSupport::incidence(todoItem);
+        if (incidence->recurs()) {
+            for (const auto &instance : mCalendar->instances(incidence)) {
+                (void) mChanger->deleteIncidence(mCalendar->item(instance), this);
+            }
+        }
         (void) mChanger->deleteIncidence(todoItem, this);
     }
 }
 
-void CalendarView::deleteTodoIncidence(const Akonadi::Item &todoItem, bool force)
+int CalendarView::questionIndependentChildren(const Akonadi::Item &item)
 {
-    const KCalendarCore::Todo::Ptr todo = CalendarSupport::todo(todoItem);
-    if (!todo) {
-        return;
-    }
-
-    // it a simple todo, ask and delete it.
-    if (mCalendar->childItems(todoItem.id()).isEmpty()) {
-        bool doDelete = true;
-        if (!force && KOPrefs::instance()->mConfirm) {
-            doDelete = (msgItemDelete(todoItem) == KMessageBox::Continue);
-        }
-        if (doDelete && !mChanger->deletedRecently(todoItem.id())) {
-            (void) mChanger->deleteIncidence(todoItem, this);
-        }
-        return;
-    }
-
-    /* Ok, this to-do has sub-to-dos, ask what to do */
-    int km = KMessageBox::No;
-    if (!force) {
+    int km;
+    auto incidence = CalendarSupport::incidence(item);
+    if (!incidence->hasRecurrenceId() && !mCalendar->childItems(item.id()).isEmpty()) {
         km = KMessageBox::questionYesNoCancel(this,
-                                              i18n("The item \"%1\" has sub-to-dos. "
-                                                   "Do you want to delete just this item and "
-                                                   "make all its sub-to-dos independent, or "
-                                                   "delete the to-do with all its sub-to-dos?",
-                                                   todo->summary()),
-                                              i18n("KOrganizer Confirmation"),
-                                              KGuiItem(i18n("Delete Only This")),
-                                              KGuiItem(i18n("Delete All")));
-    }
-    // Delete only the father
-    if (km == KMessageBox::Yes) {
-        startMultiModify(i18n("Delete parent to-do"));
-        makeChildrenIndependent(todoItem);
-        if (!mChanger->deletedRecently(todoItem.id())) {
-            (void) mChanger->deleteIncidence(todoItem, this);
+                                                i18n("The item \"%1\" has sub-to-dos. "
+                                                    "Do you want to delete just this item and "
+                                                    "make all its sub-to-dos independent, or "
+                                                    "delete the to-do with all its sub-to-dos?",
+                                                    incidence->summary()),
+                                                i18n("KOrganizer Confirmation"),
+                                                KGuiItem(i18n("Delete Only This")),
+                                                KGuiItem(i18n("Delete All")));
+
+        if (km == KMessageBox::No) {
+            km = KMessageBox::Continue;
         }
-    } else if (km == KMessageBox::No) {
-        startMultiModify(i18n("Delete parent to-do and sub-to-dos"));
-        // Delete all
-        // we have to hide the delete confirmation for each itemDate
-        deleteSubTodosIncidence(todoItem);
+    } else {
+        km = msgItemDelete(item);
     }
-    endMultiModify();
+    return km;
 }
 
 bool CalendarView::deleteIncidence(const Akonadi::Item &item, bool force)
@@ -2200,7 +2193,7 @@ bool CalendarView::deleteIncidence(const Akonadi::Item &item, bool force)
             qCCritical(KORGANIZER_LOG) << "Null incidence";
             KNotification::beep();
         }
-        qCCritical(KORGANIZER_LOG) << "CalendarView::deleteIncidence(): Unable do delete, incidence is null.";
+        qCCritical(KORGANIZER_LOG) << "CalendarView::deleteIncidence(): Unable to delete, incidence is null.";
         return false;
     }
 
@@ -2224,111 +2217,113 @@ bool CalendarView::deleteIncidence(const Akonadi::Item &item, bool force)
         return false;
     }
 
-    // If it is a todo, there are specific delete function
+    QDate itemDate = mViewManager->currentSelectionDate();
 
-    if (incidence && incidence->type() == KCalendarCore::Incidence::TypeTodo) {
-        deleteTodoIncidence(item, force);
-        return true;
+    int km;
+    if (force) {
+        km = ItemActions::All;
+    } else if (!incidence->recurs()) {  // Non-recurring, or instance of recurring.
+        km = questionIndependentChildren(item);
+    } else { // Recurring incidence
+        if (!itemDate.isValid()) {
+            qCDebug(KORGANIZER_LOG) << "Date Not Valid";
+            km = KMessageBox::warningContinueCancel(this,
+                                                    i18n("The calendar item \"%1\" recurs over multiple dates; "
+                                                            "are you sure you want to delete it "
+                                                            "and all its recurrences?",
+                                                            incidence->summary()),
+                                                    i18n("KOrganizer Confirmation"),
+                                                    KGuiItem(i18n("Delete All")));
+        } else {
+            QDateTime itemDateTime(itemDate, {}, Qt::LocalTime);
+            bool isFirst = !incidence->recurrence()->getPreviousDateTime(itemDateTime).isValid();
+            bool isLast = !incidence->recurrence()->getNextDateTime(itemDateTime).isValid();
+
+            QString message;
+            QString itemFuture(i18n("Also Delete &Future")); // QT5 was a KGuiItem
+
+            if (!isFirst && !isLast) {
+                message = i18n(
+                    "The calendar item \"%1\" recurs over multiple dates. "
+                    "Do you want to delete only the current one on %2, also "
+                    "future occurrences, or all its occurrences?",
+                    incidence->summary(),
+                    QLocale::system().toString(itemDate, QLocale::LongFormat));
+            } else {
+                message = i18n(
+                    "The calendar item \"%1\" recurs over multiple dates. "
+                    "Do you want to delete only the current one on %2 "
+                    "or all its occurrences?",
+                    incidence->summary(),
+                    QLocale::system().toString(itemDate, QLocale::LongFormat));
+            }
+
+            if (!(isFirst && isLast)) {
+                QDialogButtonBox::StandardButton returnValue = PIMMessageBox::fourBtnMsgBox(this,
+                                                                                            QMessageBox::Warning,
+                                                                                            message,
+                                                                                            i18n("KOrganizer Confirmation"),
+                                                                                            i18n("Delete C&urrent"),
+                                                                                            itemFuture,
+                                                                                            i18n("Delete &All"));
+                switch (returnValue) {
+                case QDialogButtonBox::Ok:
+                    if (!mCalendar->childItems(item.id()).isEmpty()) {
+                        km = questionIndependentChildren(item);
+                    } else {
+                        km = ItemActions::All;
+                    }
+                    break;
+                case QDialogButtonBox::Yes:
+                    km = ItemActions::Current;
+                    break;
+                case QDialogButtonBox::No:
+                    km = ItemActions::AlsoFuture;
+                    break;
+                case QDialogButtonBox::Cancel:
+                default:
+                    km = KMessageBox::Cancel;
+                    break;
+                }
+            } else {
+                km = questionIndependentChildren(item);
+            }
+        }
     }
 
-    if (incidence->recurs()) {
-        QDate itemDate = mViewManager->currentSelectionDate();
-        int km = KMessageBox::Ok;
-        if (!force) {
-            if (!itemDate.isValid()) {
-                qCDebug(KORGANIZER_LOG) << "Date Not Valid";
-                km = KMessageBox::warningContinueCancel(this,
-                                                        i18n("The calendar item \"%1\" recurs over multiple dates; "
-                                                             "are you sure you want to delete it "
-                                                             "and all its recurrences?",
-                                                             incidence->summary()),
-                                                        i18n("KOrganizer Confirmation"),
-                                                        KGuiItem(i18n("Delete All")));
-            } else {
-                QDateTime itemDateTime(itemDate, {}, Qt::LocalTime);
-                bool isFirst = !incidence->recurrence()->getPreviousDateTime(itemDateTime).isValid();
-                bool isLast = !incidence->recurrence()->getNextDateTime(itemDateTime).isValid();
+    KCalendarCore::Incidence::Ptr oldIncidence(incidence->clone());
+    KCalendarCore::Recurrence *recur = incidence->recurrence();
 
-                QString message;
-                QString itemFuture(i18n("Also Delete &Future")); // QT5 was a KGuiItem
+    switch (km) {
+    case ItemActions::All:
+        startMultiModify(i18n("Delete \"%1\"", incidence->summary()));
+        deleteChildren(item);
+        deleteRecurringIncidence(item);
+        endMultiModify();
+        break;
 
-                if (!isFirst && !isLast) {
-                    message = i18n(
-                        "The calendar item \"%1\" recurs over multiple dates. "
-                        "Do you want to delete only the current one on %2, also "
-                        "future occurrences, or all its occurrences?",
-                        incidence->summary(),
-                        QLocale::system().toString(itemDate, QLocale::LongFormat));
-                } else {
-                    message = i18n(
-                        "The calendar item \"%1\" recurs over multiple dates. "
-                        "Do you want to delete only the current one on %2 "
-                        "or all its occurrences?",
-                        incidence->summary(),
-                        QLocale::system().toString(itemDate, QLocale::LongFormat));
-                }
+    case ItemActions::Parent:
+        startMultiModify(i18n("Delete \"%1\"", incidence->summary()));
+        makeChildrenIndependent(item);
+        deleteRecurringIncidence(item);
+        endMultiModify();
+        break;
 
-                if (!(isFirst && isLast)) {
-                    QDialogButtonBox::StandardButton returnValue = PIMMessageBox::fourBtnMsgBox(this,
-                                                                                                QMessageBox::Warning,
-                                                                                                message,
-                                                                                                i18n("KOrganizer Confirmation"),
-                                                                                                i18n("Delete C&urrent"),
-                                                                                                itemFuture,
-                                                                                                i18n("Delete &All"));
-                    switch (returnValue) {
-                    case QDialogButtonBox::Ok:
-                        km = KMessageBox::Ok;
-                        break;
-                    case QDialogButtonBox::Yes:
-                        km = KMessageBox::Yes;
-                        break;
-                    case QDialogButtonBox::No:
-                        km = KMessageBox::No;
-                        break;
-                    case QDialogButtonBox::Cancel:
-                    default:
-                        km = KMessageBox::Cancel;
-                        break;
-                    }
-                } else {
-                    km = msgItemDelete(item);
-                }
-            }
+    case ItemActions::Current:
+        if (recur->allDay()) {
+            recur->addExDate(itemDate);
+        } else {
+            auto itemDateTime = recur->startDateTime();
+            itemDateTime.setDate(itemDate);
+            recur->addExDateTime(itemDateTime);
         }
-        KCalendarCore::Incidence::Ptr oldIncidence(incidence->clone());
-        KCalendarCore::Recurrence *recur = incidence->recurrence();
-        switch (km) {
-        case KMessageBox::Ok: // Continue // all
-        case KMessageBox::Continue:
-            (void) mChanger->deleteIncidence(item, this);
-            break;
+        (void) mChanger->modifyIncidence(item, oldIncidence, this);
+        break;
 
-        case KMessageBox::Yes: // just this one
-            if (recur->allDay()) {
-                recur->addExDate(itemDate);
-            } else {
-                auto itemDateTime = recur->startDateTime();
-                itemDateTime.setDate(itemDate);
-                recur->addExDateTime(itemDateTime);
-            }
-            (void) mChanger->modifyIncidence(item, oldIncidence, this);
-            break;
-
-        case KMessageBox::No: // all future items
-            recur->setEndDate(itemDate.addDays(-1));
-            (void) mChanger->modifyIncidence(item, oldIncidence, this);
-            break;
-        }
-    } else {
-        bool doDelete = true;
-        if (!force && KOPrefs::instance()->mConfirm) {
-            doDelete = (msgItemDelete(item) == KMessageBox::Continue);
-        }
-        if (doDelete) {
-            (void) mChanger->deleteIncidence(item, this);
-            processIncidenceSelection(Akonadi::Item(), QDate());
-        }
+    case ItemActions::AlsoFuture:
+        recur->setEndDate(itemDate.addDays(-1));
+        (void) mChanger->modifyIncidence(item, oldIncidence, this);
+        break;
     }
     return true;
 }
