@@ -44,6 +44,8 @@ public:
 
 private Q_SLOTS:
     void popupMenu(const QPoint &point);
+    void slotDeleteSelection();
+    void slotEditSelection();
     void slotHelpRequested();
 
 Q_SIGNALS:
