@@ -6,8 +6,7 @@
   SPDX-License-Identifier: GPL-2.0-or-later WITH Qt-Commercial-exception-1.0
 */
 
-#ifndef KORG_SEARCHCOLLECTIONHELPER_H
-#define KORG_SEARCHCOLLECTIONHELPER_H
+#pragma once
 
 #include <QObject>
 #include <QString>
@@ -43,4 +42,3 @@ private:
     Akonadi::Collection mDeclineCollection;
 };
 }
-#endif
