@@ -7,8 +7,7 @@
   SPDX-License-Identifier: GPL-2.0-or-later WITH Qt-Commercial-exception-1.0
 */
 
-#ifndef KORG_KOEVENTPOPUPMENU_H
-#define KORG_KOEVENTPOPUPMENU_H
+#pragma once
 
 #include <QDate>
 #include <QMenu>
@@ -112,4 +111,3 @@ private:
     QAction *mDissociateOccurrences = nullptr;
 };
 
-#endif
