@@ -28,8 +28,10 @@
 #include <KSharedConfig>
 #include <KShortcutsDialog>
 #include <KStandardAction>
+#include <KToolBar>
 #include <QLabel>
 #include <QStatusBar>
+#include <kxmlgui_version.h>
 #ifdef WITH_KUSERFEEDBACK
 #include "userfeedback/userfeedbackmanager.h"
 #include <KUserFeedback/NotificationPopup>
@@ -51,7 +53,7 @@ KOrganizer::KOrganizer()
     mCalendarView->setObjectName(QStringLiteral("KOrganizer::CalendarView"));
     setCentralWidget(mCalendarView);
 
-    mActionManager = new ActionManager(this, mCalendarView, this, this, false, menuBar());
+    mActionManager = new ActionManager(this, mCalendarView, this, this, false, menuBar(), toolBar());
     (void)new KOrganizerIfaceImpl(mActionManager, this, QStringLiteral("IfaceImpl"));
 
 #ifdef WITH_KUSERFEEDBACK
@@ -173,7 +175,11 @@ void KOrganizer::initActions()
 
 void KOrganizer::slotEditKeys()
 {
+#if KXMLGUI_VERSION < QT_VERSION_CHECK(5,84,0)
     KShortcutsDialog::configure(actionCollection(), KShortcutsEditor::LetterShortcutsAllowed);
+#else
+    KShortcutsDialog::showDialog(actionCollection(), KShortcutsEditor::LetterShortcutsAllowed);
+#endif
 }
 
 bool KOrganizer::queryClose()
